#
# spec file for package sword
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         libver 1_7_4
%define	        libinstver 1.7.4

Name:           sword
Version:        1.7.4
Release:        4.4
Summary:        Framework for manipulating Bible texts
License:        GPL-2.0
Group:          Development/Libraries/C and C++
Url:            http://www.crosswire.org/sword
Source0:        %{name}-%{version}.tar.bz2
Source1:        %{name}-rpmlintrc
Patch1:         sword-1.7.1-curl.patch
Requires:       libsword-%{libver} = %version
BuildRequires:  curl-devel
BuildRequires:  gcc-c++
BuildRequires:  icu
BuildRequires:  libicu-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
#
# openSUSE
#
%if 0%{?suse_version}
BuildRequires:  clucene-core-devel
Recommends:     sword-bible
Recommends:     sword-commentary
Recommends:     sword-frontend
%endif
#
# Fedora
#
%if 0%{?fedora_version}
BuildRequires:  clucene-core-devel
%endif
#
# Mandriva
#
%if 0%{?mandriva_version}
%ifarch x86_64
BuildRequires:  lib64clucene-devel
%else
BuildRequires:  libclucene-devel
%endif
%endif
#
# CentOS
#
%if ( %{defined centos_version} && 0%{?centos_version} < 600 )
BuildRequires:  sqlite
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The SWORD Project is an effort to create an ever expanding software package for
research and study of God and His Word.

The SWORD Bible Framework allows easy manipulation of Bible texts, commentaries,
lexicons, dictionaries, etc.  Many frontends are build using this framework.
An installed module set may be shared between any frontend using the framework.

%package -n libsword-%{libver}
Summary:        Shared library for sword
Group:          Development/Libraries/Other
Provides:       libsword = %{version}
Provides:       libsword%{libver}

%description -n libsword-%{libver}
This package contains the shared library for applications using sword.

%package devel
Summary:        Include files and static libraries for developing sword applications
Group:          Development/Libraries/Other
%if 0%{?centos_version} < 600
Requires:       curl-devel
%else
Requires:       libcurl-devel
%endif
Requires:       sword = %{version}

%description devel
Include files and static libraries for developing sword applications. This package
is required to compile Sword frontends, too.

%prep
%setup -q
%patch1 -p1

%build

%if 0%{?mandriva_version}
autoreconf
%endif

%configure --disable-static \
           --with-icu \
           --enable-tests \
           --enable-examples
make %{?_smp_mflags}

%check
cd tests/testsuite
# && ./runall.sh
TESTSUITE=$(for i in *.good; do basename $i .good; done)
for i in $TESTSUITE; do
	case $i in
		osis*)
			continue
		;;
		*)
			echo -n "$i: "
			./runtest.sh $i -q
		    if [ $? -ne 0 ]; then
		        echo FAILED
		        echo ""
		        echo To see problems, try running:
		        echo ./runtest.sh $i
		        echo ""
		        exit 1
		    else
		        echo PASSED.
		    fi
		;;
	esac
done

%install
%make_install install_config
rm %{buildroot}/%{_libdir}/*.la
pushd %{buildroot}/%{_bindir}
strip *
strip %{buildroot}/%{_libdir}/libsword*.so
popd

%post -n libsword-%{libver} -p /sbin/ldconfig

%postun -n libsword-%{libver} -p /sbin/ldconfig

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog LICENSE NEWS README doc/translation-template.conf
%config(noreplace) %{_sysconfdir}/sword.conf
%{_bindir}/*
%dir %{_datadir}/sword
%dir %{_datadir}/sword/locales.d
%dir %{_datadir}/sword/mods.d
%{_datadir}/sword/locales.d/*
%{_datadir}/sword/mods.d/globals.conf

%files -n libsword-%{libver}
%defattr(-,root,root)
%{_libdir}/libsword-%{libinstver}.so

%files devel
%defattr(-,root,root)
%doc CODINGSTYLE
%{_includedir}/*
%{_libdir}/pkgconfig/sword.pc
%{_libdir}/*.so
%exclude %{_libdir}/libsword-%{libinstver}.so

%changelog
* Sun Dec 28 2014 lars@linux-schulserver.de
- update to 1.7.4:
  + Fixed endless loop in osis2mod for some inputs.
  + Added support for Psalm Book divisions using
    <div type=majorSection> from GHellings
  + Corrected anomalous OSIS highlighting output w/GHellings'
    patches in src/modules/filters/osis{plain,xhtml}.cpp
* Wed May 14 2014 riggwelter@opensuse.org
- update to 1.7.3:
  + Added support for xz (LZMA2) module compression via liblzma
  + Added support for bzip2 (Burrows-Wheeler) module compression via
    libbz2
  + Added zVerse4, zText4, & zCom4 classes to support compressed
    text/commentary modules with entry sizes > 64k
  + Added C# bindings contributed by Daniel Hughes
    <trampster@gmail.com>
* Tue Dec 31 2013 lars@linux-schulserver.de
- update to 1.7.1:
  Many new versifications and locale, large scale refactoring and
  standardisation of many methods and the addition of filters for
  standard compliant XHTML output are probably the most important
  improvements.
  Improved output in various formats, handling of bibliographic data
  and addition of new transports to the install manager are other
  changes.
  We will from now on maintain both a maintenance branch for 1.7 and
  a development branch for new features.
  Some entries from Changelog:
  + Add a new Option filter, OSISReferenceLinks
  + Removed PLAINHTML and PLAINFootnotes filters
  + More examples, including: show a chapter, verse range
  + Greatly improved navigation with intros and normalization
    turned on/off
  + New .conf entries honored:
    StrongsPadding=false, which turns off
    logic to detect strongs numbers and add padding
    CaseSensitiveKeys=true, which makes a lexicon case sensitive
  + Added support to install from SFTP sources using username/password
    authentication in places where cURL has SFTP support (no support
    for public-key auth yet)
  + Starting (very minimal) support for TEI in xml2gbs
  + Changed default log level to WARN from INFO
  + New Lucene index field for searching 'morph'
  + InstallMgr now supports HTTPS connections where cURL has support
    for that transport
  + Allow div in header of osis document
  + Allow comments to be in osis document and to be stripped out
  + Added ability for *HTML* wrappers to render n attribute from notes
  + Removed SynodalP v11n from library
  + Improved handling of CLucene and included support for CLucene 2
  + Added RTFHTML parsing of rtf \\number codes to facilitate .conf files
  + Added sane parameter parsing to imp2ld
  + Added methods for utf8 / wchar conversion to help clucene
  + added Faroese, Pohnpeian Locale
- disabled osis testsuite for the moment
- removed sword-gcc47.patch and
- adapted sword-1.6.1-curl.patch (sword-1.7.1-curl.patch)
- removed sword-1.6.1-fix_compiler_warnings.patch
- added rpmlintrc to ignore notes for the examples
* Fri Mar 16 2012 dimstar@opensuse.org
- Add sword-gcc47.patch: Fix build with gcc 4.7.
* Thu Sep  8 2011 kirill.kirillov@gmail.com
- added sword-1.6.2-fix_build_with_new_curl.patch
* Sat Dec 18 2010 lars@linux-schulserver.de
- update to 1.6.2:
  + Fixed imp2vs not flushing cache before exiting when
    creating compressed modules
  + Fixed LZSS compression
  + Fixed parsing book names containing the letter 'f'
  + Added support for building Python and Perl with CMake
  + Allow <hi> to be nested in any order in OSIS markup
    Updates to allow hyphenated book names
  + Set verse to 1 when changing chapter and book in VerseKey
  + Fixed a bug where book designations ending in 'f' would
    trigger the verse+'f'/'ff' feature.
  + Fixed curl bug which seems to hold on to progress
    object even after scope of data retrival
* Wed Aug 18 2010 lars@linux-schulserver.de
- include sword-1.6.1-curl.patch from Karl Kleinpaste to fix a
  problem with SWORD and latest curl. Thanks to Gary Holmlund for
  the hint.
* Sun Mar 28 2010 lars@linux-schulserver.de
- update to 1.6.1:
  + Added locales.d/locales.conf - a special locale which can be
    queried for localize and English lang names
  + Updated installmgr util to allow multiple commands and
    update dl progress
  + Added checks for Hebrew and Arabic when stripping for searching
  + Added initial impl for CurlHTTPTransport
  + Added progress reporting to FtpLib transport
  + Added ability to cancel during file transport
- reworked sword-1.6.1-fix_compiler_warnings.patch
- remove all other patches
- buildrequire zlib-devel to enable zlib support
* Sun Dec 13 2009 lars@linux-schulserver.de
- fix build for Mandriva and Fedora
* Wed Jul 22 2009 lars@linux-schulserver.de
- update to 1.6.0:
  + Added list support in OSIS HTML conversion
  + Added fallback checks for OS specific module locations:
  ++$ALLUSERSPROFILE/Application Data/sword
    additionally looked for at:
  ++ $HOMEDRIVE$HOMEPATH/Application Data
  ++ added ~/sword (note the absense of '.')
  + added new bookname translations
  + general cleanup and bugfixing
- use/adapt debian patches:
  + sword-1.6.0-closing_section_not_chapter.patch
  + sword-1.6.0-fix_compiler_warnings.patch
  + sword-1.6.0-fix_osis2mod_compression_default.patch
  + sword-1.6.0-missing_includes.patch
  + sword-1.6.0-regex_only_when_needed.patch
- disable static lib
- enable icu
- enable tests (disable verseparsing test for now)
- enable examples
- strip binaries and lib
* Thu Sep 25 2008 lars@linux-schulserver.de
- moved to Education base repository
* Mon Jun  9 2008 lars@linux-schulserver.de
- recommend sword-bible, so language specific bibles can be
  installed automatically
- recommend sword-commentary
* Sun Jun  8 2008 lars@linux-schulserver.de
- update to 1.5.11:
  + Added ability for lexicon drivers to accept
    [#]###![a-z] as strong number.
  + Added basic TEIRTF filters
  + Added tei2mod utility
  + Added Japanese locale from http://bible.50webs.org/en/
  + Applied Ben Morgan's TEIHTMLHREF filter
  + Added TEIHTMLHREF filter to BCB5 project
  + Applied patch to better handle x-refs in notes
  + Applied patch to better output OSIS in plaintext
  + Updated rawstr and rawstr4 to work consistently with
    buffer sizes
  + Updated Farsi and French locales
  + Implemented a basic TreeKeyIdx::remove() method
- removed upstreamed sword-gcc43.patch
* Mon May 19 2008 lars@linux-schulserver.de
- fix rpm groups
- added patches from fedora to build with gcc4.3
- own the directories in %%_datadir/sword
* Sun Dec 23 2007 lars@linux-schulserver.de
- initial package for openSUSE-Education
